==> grafana-7.5.0.tar.gz: grafana-7.5.0/docs/sources/panels/visualizations/time-series/graph-time-series-as-points.md <==
+++
title = "Graph time series as points"
keywords = ["grafana", "time series panel", "documentation", "guide", "graph"]
weight = 300
+++

# Graph time series as points

> **Note:** This is a beta feature. Time series panel is going to replace the Graph panel in the future releases.

This section explains how to use Time series field options to visualize time series data as points and illustrates what the options do.

## Create the panel

1. [Add a panel](https://grafana.com/docs/grafana/latest/panels/add-a-panel/). Select the [Time series]({{< relref "_index.md" >}}) visualization.
1. In the [Panel editor](https://grafana.com/docs/grafana/latest/panels/panel-editor/), click the **Field** tab.
1. In Style, click **Points**.

## Style the points

Use the following field settings to refine your visualization.

For more information about applying these options, refer to:

- [Configure all fields]({{< relref "../../field-options/configure-all-fields.md" >}})
- [Configure specific fields]({{< relref "../../field-options/configure-specific-fields.md" >}})

Some field options will not affect the visualization until you click outside of the field option box you are editing or press Enter.

### Point size

Set the size of the points, from 1 to 40 pixels in diameter.

Point size set to 6:

![Show points point size 6 example](/img/docs/time-series-panel/points-graph-show-points-6-7-4.png)

Point size set to 20:

![Show points point size 20 example](/img/docs/time-series-panel/points-graph-show-points-20-7-4.png)

Point size set to 35:

![Show points point size 35 example](/img/docs/time-series-panel/points-graph-show-points-35-7-4.png)

==> grafana-7.5.15.tar.gz: grafana-7.5.15/docs/sources/panels/visualizations/time-series/graph-time-series-as-points.md <==
+++
title = "Graph time series as points"
keywords = ["grafana", "time series panel", "documentation", "guide", "graph"]
weight = 300
+++

# Graph time series as points

> **Note:** This is a beta feature. Time series panel is going to replace the Graph panel in the future releases.

This section explains how to use Time series field options to visualize time series data as points and illustrates what the options do.

## Create the panel

1. [Add a panel]({{< relref "../../add-a-panel.md" >}}). Select the [Time series]({{< relref "_index.md" >}}) visualization.
1. In the [Panel editor]({{< relref "../../panel-editor.md" >}}), click the **Field** tab..
1. In Style, click **Points**.

## Style the points

Use the following field settings to refine your visualization.

For more information about applying these options, refer to:

- [Configure all fields]({{< relref "../../field-options/configure-all-fields.md" >}})
- [Configure specific fields]({{< relref "../../field-options/configure-specific-fields.md" >}})

Some field options will not affect the visualization until you click outside of the field option box you are editing or press Enter.

### Point size

Set the size of the points, from 1 to 40 pixels in diameter.

Point size set to 6:

![Show points point size 6 example](/static/img/docs/time-series-panel/points-graph-show-points-6-7-4.png)

Point size set to 20:

![Show points point size 20 example](/static/img/docs/time-series-panel/points-graph-show-points-20-7-4.png)

Point size set to 35:

![Show points point size 35 example](/static/img/docs/time-series-panel/points-graph-show-points-35-7-4.png)
